@@ -1,14 +1,18 @@
 class Color:
     def __init__(self, r, g, b):
-        self.red = r
+        self.red   = r
         self.green = g
-        self.blue = b
+        self.blue  = b
 
-    def adjust_brightness(self, alpha):
-        # Super hacky, pygame.draw.rect() doesn't support alpha blending
-        self.red *= alpha
+    def adjust_brightness(self, alpha, to_int = False):
+        self.red   *= alpha
         self.green *= alpha
-        self.blue *= alpha
+        self.blue  *= alpha
+
+        if to_int:
+            self.red   = int(self.red)
+            self.green = int(self.green)
+            self.blue  = int(self.blue)
 
     def to_tuple(self):
         return (self.red, self.green, self.blue)
